ipsec whack --impair omit_v2_ike_auth_child
ipsec auto --up westnet-eastnet-ipv4-psk-ikev2
echo done
